#ifndef PATHNAMES_H
#define PATHNAMES_H


/* Program's home directory. */
#define PATHNAME_HOME			".imapfilter"

/* Program's configuration file. */
#define PATHNAME_CONFIG			PATHNAME_HOME "/config.lua"

/* Lua imapfilter interface functions file. */
#define PATHNAME_INTERFACE		MAKEFILE_SHAREDIR "/interface.lua"

/* Lua imapfilter auxiliary functions file. */
#define PATHNAME_AUXILIARY		MAKEFILE_SHAREDIR "/auxiliary.lua"

/* SSL/TLS certificates file. */
#define PATHNAME_CERTS			PATHNAME_HOME "/certificates"

/* Debug temporary file template. */
#define PATHNAME_DEBUG			PATHNAME_HOME "/debug.XXXXXX"


#endif				/* PATHNAMES_H */
